@@ -21,7 +21,6 @@ ac_cv_sizeof_unsigned_long_long=8
 ac_cv_sizeof_unsigned_short=2
 ac_cv_sizeof_unsigned_short=2
 ac_cv_sizeof_void_p=4
-ac_cv_sizeof_off_t=4
 # DB2, DB3
 db_cv_alignp_t=int
 db_cv_fcntl_f_setfd=yes
@@ -47,8 +46,4 @@ fi
 if [ -z "$HAVE_PKG_CACHE" ]; then
 	# only needed until the packages provide these directly
 	# using the mechanism above.
-	# parted
-	if [ "$PACKAGE" = "parted" -o "$PACKAGE_NAME" = "GNU parted" ]; then
-		ac_cv_sizeof_off_t=8
-	fi
 fi
